/*****************************************************************************
* SPSSload_KID_2006_Severity.SPS
* This program will load the 2006 KID ASCII Severity File into SPSS.
*****************************************************************************/

*** Read data elements from the ASCII file ***.
DATA LIST FILE = 'KID_2006_Severity.ASC' FIXED / 
    HOSPID                     1-  5
    RECNUM                     6- 13
    APRDRG                    14- 17
    APRDRG_R                  18- 19
    APRDRG_S                  20- 21
    APSDRG                    22- 26
    APSDRG_C                  27- 36
    APSDRG_L                  37- 46
    APSDRG_M                  47- 56
    CM_AIDS                   57- 58
    CM_ALCOH                  59- 60
    CM_ANEMD                  61- 62
    CM_ARTH                   63- 64
    CM_BLDLO                  65- 66
    CM_CHF                    67- 68
    CM_CHRNL                  69- 70
    CM_COAG                   71- 72
    CM_DEPRE                  73- 74
    CM_DM                     75- 76
    CM_DMCX                   77- 78
    CM_DRUG                   79- 80
    CM_HTN_C                  81- 82
    CM_HYPOT                  83- 84
    CM_LIVER                  85- 86
    CM_LYMPH                  87- 88
    CM_LYTES                  89- 90
    CM_METS                   91- 92
    CM_NEURO                  93- 94
    CM_OBESE                  95- 96
    CM_PARA                   97- 98
    CM_PERIV                  99-100
    CM_PSYCH                 101-102
    CM_PULMC                 103-104
    CM_RENLF                 105-106
    CM_TUMOR                 107-108
    CM_ULCER                 109-110
    CM_VALVE                 111-112
    CM_WGHTL                 113-114
    DS_DX_Ca                 115-119 (A)
    DS_LOS_L                 120-121
    DS_LOS_S                 122-133
    DS_Mrt_L                 134-135
    DS_Mrt_S                 136-147
    DS_RD_Le                 148-149
    DS_RD_Sc                 150-161
    DS_Stage                 162-166.

***  Specify write formats  ***.
FORMATS
    HOSPID                   (F5.0) /
    RECNUM                   (F8.0) /
    APRDRG                   (F4.0) /
    APRDRG_R                 (F2.0) /
    APRDRG_S                 (F2.0) /
    APSDRG                   (F5.0) /
    APSDRG_C                 (F10.5) /
    APSDRG_L                 (F10.5) /
    APSDRG_M                 (F10.5) /
    CM_AIDS                  (F2.0) /
    CM_ALCOH                 (F2.0) /
    CM_ANEMD                 (F2.0) /
    CM_ARTH                  (F2.0) /
    CM_BLDLO                 (F2.0) /
    CM_CHF                   (F2.0) /
    CM_CHRNL                 (F2.0) /
    CM_COAG                  (F2.0) /
    CM_DEPRE                 (F2.0) /
    CM_DM                    (F2.0) /
    CM_DMCX                  (F2.0) /
    CM_DRUG                  (F2.0) /
    CM_HTN_C                 (F2.0) /
    CM_HYPOT                 (F2.0) /
    CM_LIVER                 (F2.0) /
    CM_LYMPH                 (F2.0) /
    CM_LYTES                 (F2.0) /
    CM_METS                  (F2.0) /
    CM_NEURO                 (F2.0) /
    CM_OBESE                 (F2.0) /
    CM_PARA                  (F2.0) /
    CM_PERIV                 (F2.0) /
    CM_PSYCH                 (F2.0) /
    CM_PULMC                 (F2.0) /
    CM_RENLF                 (F2.0) /
    CM_TUMOR                 (F2.0) /
    CM_ULCER                 (F2.0) /
    CM_VALVE                 (F2.0) /
    CM_WGHTL                 (F2.0) /
    DS_LOS_L                 (F2.0) /
    DS_LOS_S                 (F12.5) /
    DS_Mrt_L                 (F2.0) /
    DS_Mrt_S                 (F12.5) /
    DS_RD_Le                 (F2.0) /
    DS_RD_Sc                 (F12.5) /
    DS_Stage                 (F5.2) .

***  Assign labels to the data elements ***.
VARIABLE LABELS 
    HOSPID                   "HCUP hospital identification number"
    RECNUM                   "HCUP record number"
    APRDRG                   "All Patient Refined DRG"
    APRDRG_R                 "All Patient Refined DRG: Risk of Mortality Subclass"
    APRDRG_S                 "All Patient Refined DRG: Severity of Illness Subclass"
    APSDRG                   "All-Payer Severity-adjusted DRG"
    APSDRG_C                 "All-Payer Severity-adjusted DRG: Charge Weight"
    APSDRG_L                 "All-Payer Severity-adjusted DRG: Length of Stay Weight"
    APSDRG_M                 "All-Payer Severity-adjusted DRG: Mortality Weight"
    CM_AIDS                  "AHRQ comorbidity measure: Acquired immune deficiency syndrome"
    CM_ALCOH                 "AHRQ comorbidity measure: Alcohol abuse"
    CM_ANEMD                 "AHRQ comorbidity measure: Deficiency anemias"
    CM_ARTH                  "AHRQ comorbidity measure: Rheumatoid arthritis/collagen vascular diseases"
    CM_BLDLO                 "AHRQ comorbidity measure: Chronic blood loss anemia"
    CM_CHF                   "AHRQ comorbidity measure: Congestive heart failure"
    CM_CHRNL                 "AHRQ comorbidity measure: Chronic pulmonary disease"
    CM_COAG                  "AHRQ comorbidity measure: Coagulopathy"
    CM_DEPRE                 "AHRQ comorbidity measure: Depression"
    CM_DM                    "AHRQ comorbidity measure: Diabetes, uncomplicated"
    CM_DMCX                  "AHRQ comorbidity measure: Diabetes with chronic complications"
    CM_DRUG                  "AHRQ comorbidity measure: Drug abuse"
    CM_HTN_C                 "AHRQ comorbidity measure: Hypertension (combine uncomplicated and complicated)"
    CM_HYPOT                 "AHRQ comorbidity measure: Hypothyroidism"
    CM_LIVER                 "AHRQ comorbidity measure: Liver disease"
    CM_LYMPH                 "AHRQ comorbidity measure: Lymphoma"
    CM_LYTES                 "AHRQ comorbidity measure: Fluid and electrolyte disorders"
    CM_METS                  "AHRQ comorbidity measure: Metastatic cancer"
    CM_NEURO                 "AHRQ comorbidity measure: Other neurological disorders"
    CM_OBESE                 "AHRQ comorbidity measure: Obesity"
    CM_PARA                  "AHRQ comorbidity measure: Paralysis"
    CM_PERIV                 "AHRQ comorbidity measure: Peripheral vascular disorders"
    CM_PSYCH                 "AHRQ comorbidity measure: Psychoses"
    CM_PULMC                 "AHRQ comorbidity measure: Pulmonary circulation disorders"
    CM_RENLF                 "AHRQ comorbidity measure: Renal failure"
    CM_TUMOR                 "AHRQ comorbidity measure: Solid tumor without metastasis"
    CM_ULCER                 "AHRQ comorbidity measure: Peptic ulcer disease excluding bleeding"
    CM_VALVE                 "AHRQ comorbidity measure: Valvular disease"
    CM_WGHTL                 "AHRQ comorbidity measure: Weight loss"
    DS_DX_Ca                 "Disease Staging: Principal Disease Category"
    DS_LOS_L                 "Disease Staging: Length of Stay Level"
    DS_LOS_S                 "Disease Staging: Length of Stay Scale"
    DS_Mrt_L                 "Disease Staging: Mortality Level"
    DS_Mrt_S                 "Disease Staging: Mortality Scale"
    DS_RD_Le                 "Disease Staging: Resource Demand Level"
    DS_RD_Sc                 "Disease Staging: Resource Demand Scale"
    DS_Stage                 "Disease Staging: Principal Stage" .

*** Convert special values to system missing values ***.
RECODE RECNUM                   (-9999999 -8888888 -6666666=SYSMIS).
RECODE APRDRG                   (-999 -888 -666=SYSMIS).
RECODE APRDRG_R                 (-9 -8 -6 -5=SYSMIS).
RECODE APRDRG_S                 (-9 -8 -6 -5=SYSMIS).
RECODE APSDRG                   (-9999 -8888 -6666=SYSMIS).
RECODE APSDRG_C                 (-999.99999 -888.88888 -666.66666=SYSMIS).
RECODE APSDRG_L                 (-999.99999 -888.88888 -666.66666=SYSMIS).
RECODE APSDRG_M                 (-999.99999 -888.88888 -666.66666=SYSMIS).
RECODE CM_AIDS                  (-9 -8 -6 -5=SYSMIS).
RECODE CM_ALCOH                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_ANEMD                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_ARTH                  (-9 -8 -6 -5=SYSMIS).
RECODE CM_BLDLO                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_CHF                   (-9 -8 -6 -5=SYSMIS).
RECODE CM_CHRNL                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_COAG                  (-9 -8 -6 -5=SYSMIS).
RECODE CM_DEPRE                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_DM                    (-9 -8 -6 -5=SYSMIS).
RECODE CM_DMCX                  (-9 -8 -6 -5=SYSMIS).
RECODE CM_DRUG                  (-9 -8 -6 -5=SYSMIS).
RECODE CM_HTN_C                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_HYPOT                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_LIVER                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_LYMPH                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_LYTES                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_METS                  (-9 -8 -6 -5=SYSMIS).
RECODE CM_NEURO                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_OBESE                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_PARA                  (-9 -8 -6 -5=SYSMIS).
RECODE CM_PERIV                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_PSYCH                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_PULMC                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_RENLF                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_TUMOR                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_ULCER                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_VALVE                 (-9 -8 -6 -5=SYSMIS).
RECODE CM_WGHTL                 (-9 -8 -6 -5=SYSMIS).
RECODE DS_LOS_L                 (-9 -8 -6 -5=SYSMIS).
RECODE DS_LOS_S                 (-99999.99999 -88888.88888 -66666.66666=SYSMIS).
RECODE DS_Mrt_L                 (-9 -8 -6 -5=SYSMIS).
RECODE DS_Mrt_S                 (-99999.99999 -88888.88888 -66666.66666=SYSMIS).
RECODE DS_RD_Le                 (-9 -8 -6 -5=SYSMIS).
RECODE DS_RD_Sc                 (-99999.99999 -88888.88888 -66666.66666=SYSMIS).
RECODE DS_Stage                 (-9.99 -8.88 -6.66=SYSMIS).

SAVE OUTFILE = 'KID_2006_Severity.SAV' / COMPRESSED.
