/*******************************************************************
*   SPSSload_KID_2003_HOSPITAL.SPS:                               
*      THE SPSS CODE SHOWN BELOW WILL LOAD THE ASCII                
*      HOSPITAL FILE INTO SPSS                                        
*******************************************************************/


*******************************.
*  Define the data file       *.
*******************************.

DATA LIST FILE = 'KID_2003_HOSPITAL.ASC' FIXED / 
 AHAID                1-  7 (A)
 HOSPADDR             8- 37 (A)
 HOSPCITY            38- 57 (A)
 HOSPID              58- 62
 HOSPNAME            63- 92 (A)
 HOSPST              93- 94 (A)
 HOSPSTCO            95- 99
 HOSPZIP            100-104 (A)
 HOSP_BED           105-106
 HOSP_CON           107-108
 HOSP_LOC           109-110
 HOSP_LT            111-112
 HOSP_REG           113-114
 HOSP_TEA           115-116
 IDNUMBER           117-122 (A)
 KID_STRA           123-126
 NACHTYPE           127-128
 N_BRTH_U           129-134
 N_DISC_U           135-142
 N_HOSP_U           143-146
 PEDS_DIS           147-152
 PEDS_PCT           153-160
 S_BRTH_U           161-166
 S_CHLD_U           167-172
 S_CMPB_U           173-178
 S_DISC_U           179-184
 S_HOSP_U           185-188
 S_UNCB_U           189-194
 TOTAL_DI           195-200
 YEAR               201-204.


***  Specify write formats  ***.
FORMATS
 HOSPID              (F4.0) /
 HOSPSTCO            (F4.0) /
 HOSP_BED            (F3.0) /
 HOSP_CON            (F3.0) /
 HOSP_LOC            (F3.0) /
 HOSP_LT             (F3.0) /
 HOSP_REG            (F3.0) /
 HOSP_TEA            (F3.0) /
 KID_STRA            (F4.0) /
 NACHTYPE            (F3.0) /
 N_BRTH_U            (F8.0) /
 N_DISC_U            (F8.0) /
 N_HOSP_U            (F8.0) /
 PEDS_DIS            (F4.0) /
 PEDS_PCT            (F8.4) /
 S_BRTH_U            (F8.0) /
 S_CHLD_U            (F8.0) /
 S_CMPB_U            (F8.0) /
 S_DISC_U            (F8.0) /
 S_HOSP_U            (F8.0) /
 S_UNCB_U            (F8.0) /
 TOTAL_DI            (F4.0) /
 YEAR                (F3.0) .


***  Assign labels to the variables ***.
VARIABLE LABELS 
 AHAID     "AHA hospital identifier"
 HOSPADDR  "Hospital address from AHA Survey (Z011)"
 HOSPCITY  "Hospital city from AHA Survey (Z012)"
 HOSPID    "HCUP hospital identification number"
 HOSPNAME  "Hospital name from AHA Survey (Z000)"
 HOSPST    "Hospital state postal code"
 HOSPSTCO  "Hospital modified FIPS state/county code"
 HOSPZIP   "Hospital ZIP Code from AHA Survey (Z014)"
 HOSP_BED  "Bedsize of hospital"
 HOSP_CON  "Control/ownership of hospital"
 HOSP_LOC  "Location (urban/rural) of hospital"
 HOSP_LT   "Location/teaching status of hospital"
 HOSP_REG  "Region of hospital"
 HOSP_TEA  "Teaching status of hospital"
 IDNUMBER  "AHA hospital identifier without the leading 6"
 KID_STRA  "Hospital stratum used for weights"
 NACHTYPE  "NACHRI hospital type"
 N_BRTH_U  "Number of universe births in KID_STRATUM"
 N_DISC_U  "Number of universe discharges in KID_STRATUM"
 N_HOSP_U  "Number of universe hospitals in KID_STRATUM"
 PEDS_DIS  "Number of discharges, 20 years old or younger, from this hospital in the SID"
 PEDS_PCT  "Percentage of hospital discharges, 20 years old or younger"
 S_BRTH_U  "Number of sample births in KID_STRATUM"
 S_CHLD_U  "Number of sample pediatric non-births in KID_STRATUM"
 S_CMPB_U  "Number of sample complicated births in KID_STRATUM"
 S_DISC_U  "Number of sample births and children in KID_STRATUM"
 S_HOSP_U  "Number of sample hospitals in KID_STRATUM"
 S_UNCB_U  "Number of sample uncomplicated births in KID_STRATUM"
 TOTAL_DI  "Total number of discharges from this hospital in the SID"
 YEAR      "Calendar year" .


**********************************************************.
*    Convert missing data to system missing values       *.
**********************************************************.

RECODE HOSPSTCO
 (-9999,-8888,-6666,-5555=SYSMIS).
RECODE HOSP_BED
 (-9,-8,-6,-5=SYSMIS).
RECODE HOSP_CON
 (-9,-8,-6,-5=SYSMIS).
RECODE HOSP_LOC
 (-9,-8,-6,-5=SYSMIS).
RECODE HOSP_LT
 (-9,-8,-6,-5=SYSMIS).
RECODE HOSP_REG
 (-9,-8,-6,-5=SYSMIS).
RECODE HOSP_TEA
 (-9,-8,-6,-5=SYSMIS).
RECODE KID_STRA
 (-999,-888,-666,-555=SYSMIS).
RECODE NACHTYPE
 (-9,-8,-6,-5=SYSMIS).
RECODE N_BRTH_U
 (-99999,-88888,-66666,-55555=SYSMIS).
RECODE N_DISC_U
 (-9999999,-8888888,-6666666,-5555555=SYSMIS).
RECODE N_HOSP_U
 (-999,-888,-666,-555=SYSMIS).
RECODE PEDS_DIS
 (-99999,-88888,-66666,-55555=SYSMIS).
RECODE PEDS_PCT
 (-99.9999,-88.8888,-66.6666,-55.5555=SYSMIS).
RECODE S_BRTH_U
 (-99999,-88888,-66666,-55555=SYSMIS).
RECODE S_CHLD_U
 (-99999,-88888,-66666,-55555=SYSMIS).
RECODE S_CMPB_U
 (-99999,-88888,-66666,-55555=SYSMIS).
RECODE S_DISC_U
 (-99999,-88888,-66666,-55555=SYSMIS).
RECODE S_HOSP_U
 (-999,-888,-666,-555=SYSMIS).
RECODE S_UNCB_U
 (-99999,-88888,-66666,-55555=SYSMIS).
RECODE TOTAL_DI
 (-99999,-88888,-66666,-55555=SYSMIS).



SAVE OUTFILE = 'KID_2003_HOSPITAL.SAV' /COMPRESSED.
